@@ -5,7 +5,7 @@
 
 import logging
 from datetime import datetime
-from typing import Union
+from typing import Optional, Union
 
 from mvt.ios.versions import find_version_by_build
 
@@ -18,10 +18,15 @@ class AnalyticsIOSVersions(IOSExtraction):
     a timeline of build numbers from the private/var/Keychains/Analytics/*.db
     files."""
 
-    def __init__(self, file_path: str = None, target_path: str = None,
-                 results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = logging.getLogger(__name__),
-                 results: list = []) -> None:
+    def __init__(
+        self,
+        file_path: Optional[str] = None,
+        target_path: Optional[str] = None,
+        results_path: Optional[str] = None,
+        fast_mode: Optional[bool] = False,
+        log: logging.Logger = logging.getLogger(__name__),
+        results: Optional[list] = None
+    ) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
