@@ -5,7 +5,7 @@
 
 import logging
 import sqlite3
-from typing import Union
+from typing import Optional, Union
 
 from mvt.common.utils import (convert_chrometime_to_datetime,
                               convert_datetime_to_iso)
@@ -15,7 +15,6 @@ from ..base import IOSExtraction
 CHROME_FAVICON_BACKUP_IDS = [
     "55680ab883d0fdcffd94f959b1632e5fbbb18c5b"
 ]
-
 # TODO: Confirm Chrome database path.
 CHROME_FAVICON_ROOT_PATHS = [
     "private/var/mobile/Containers/Data/Application/*/Library/Application Support/Google/Chrome/Default/Favicons",
@@ -25,10 +24,15 @@ CHROME_FAVICON_ROOT_PATHS = [
 class ChromeFavicon(IOSExtraction):
     """This module extracts all Chrome favicon records."""
 
-    def __init__(self, file_path: str = None, target_path: str = None,
-                 results_path: str = None, fast_mode: bool = False,
-                 log: logging.Logger = logging.getLogger(__name__),
-                 results: list = []) -> None:
+    def __init__(
+        self,
+        file_path: Optional[str] = None,
+        target_path: Optional[str] = None,
+        results_path: Optional[str] = None,
+        fast_mode: Optional[bool] = False,
+        log: logging.Logger = logging.getLogger(__name__),
+        results: Optional[list] = None
+    ) -> None:
         super().__init__(file_path=file_path, target_path=target_path,
                          results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
@@ -83,7 +87,8 @@ class ChromeFavicon(IOSExtraction):
                 "url": row[0],
                 "icon_url": row[1],
                 "timestamp": last_timestamp,
-                "isodate": convert_datetime_to_iso(convert_chrometime_to_datetime(last_timestamp)),
+                "isodate": convert_datetime_to_iso(
+                    convert_chrometime_to_datetime(last_timestamp)),
             })
 
         cur.close()
